@@ -2,8 +2,6 @@
 check_available = function() {
   if (rstudioapi::isAvailable() == FALSE & getOption("is.job", FALSE) == FALSE)
     stop("You must run this from the RStudio main session.")
-  if (rstudioapi::getVersion() < 1.2)
-    stop("Install RStudio v1.2 or greater for the 'jobs' functionality.")
 
   invisible(TRUE)
 }
